# Changelog

## [v0.0.19](https://github.com/materialsproject/pyrho/tree/v0.0.19) (2021-03-01)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.18...v0.0.19)

## [v0.0.18](https://github.com/materialsproject/pyrho/tree/v0.0.18) (2021-03-01)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.17...v0.0.18)

## [v0.0.17](https://github.com/materialsproject/pyrho/tree/v0.0.17) (2021-03-01)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.16...v0.0.17)

## [v0.0.16](https://github.com/materialsproject/pyrho/tree/v0.0.16) (2021-03-01)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.15...v0.0.16)

**Merged pull requests:**

- Bump hypothesis from 6.3.3 to 6.3.4 [\#12](https://github.com/materialsproject/pyrho/pull/12) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump mkdocstrings from 0.14.0 to 0.15.0 [\#11](https://github.com/materialsproject/pyrho/pull/11) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump moto from 1.3.14 to 2.0.0 [\#10](https://github.com/materialsproject/pyrho/pull/10) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pytest-cov from 2.8.1 to 2.11.1 [\#9](https://github.com/materialsproject/pyrho/pull/9) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pytest-mock from 2.0.0 to 3.5.1 [\#8](https://github.com/materialsproject/pyrho/pull/8) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump mkdocs-material from 6.2.5 to 7.0.3 [\#6](https://github.com/materialsproject/pyrho/pull/6) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump flake8 from 3.7.9 to 3.8.4 [\#5](https://github.com/materialsproject/pyrho/pull/5) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.0.15](https://github.com/materialsproject/pyrho/tree/v0.0.15) (2021-02-27)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.14...v0.0.15)

## [v0.0.14](https://github.com/materialsproject/pyrho/tree/v0.0.14) (2021-02-27)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.13...v0.0.14)

**Merged pull requests:**

- Bump pycodestyle from 2.5.0 to 2.6.0 [\#7](https://github.com/materialsproject/pyrho/pull/7) ([jmmshn](https://github.com/jmmshn))
- Bump hypothesis from 5.8.3 to 6.3.3 [\#4](https://github.com/materialsproject/pyrho/pull/4) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump pre-commit from 2.0.1 to 2.10.1 [\#3](https://github.com/materialsproject/pyrho/pull/3) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v0.0.13](https://github.com/materialsproject/pyrho/tree/v0.0.13) (2021-02-27)

[Full Changelog](https://github.com/materialsproject/pyrho/compare/v0.0.12...v0.0.13)

# History

## 0.0.0 (2021-02-25)

-   Initial release on PyPI.


\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
